@@ -38,15 +38,17 @@ impact_fraction <- function(model, data, new_data, calculation_method="B",prev=N
       "data must be a dataframe object")
   }
 
-  # remove data not used to fit model
-  data <- data[row.names(data) %in% row.names(model.frame(model)),]
-  new_data <- new_data[row.names(data) %in% row.names(model.frame(model)),]
 
   if(!is.data.frame(new_data)){
     stop(
       "new_data must be a dataframe object")
   }
 
+  # remove data not used to fit model
+  data <- data[row.names(data) %in% row.names(model.frame(model)),]
+  new_data <- new_data[row.names(new_data) %in% row.names(model.frame(model)),]
+
+
   if(ncol(data)!=ncol(new_data) || nrow(data)!=nrow(new_data)){
     stop(
       "new_data must be the same dimensions as data")
@@ -472,9 +474,9 @@ if(verbose){
 
     cat(paste("Method used to produce estimate: ", x$calculation_method, "\n",sep=""))
 
-    if(is.null(x$prev)) x$prev=0.5
-    if(x$calculation_method=="Weighted Standardisation") cat(paste("Assumed prevalence: ", unique(x$prev), "\n",sep=""))
-
+    if(x$calculation_method=="Weighted Standardisation"){
+      if(!is.null(x$prev)) cat(paste("Assumed prevalence: ", unique(x$prev), "\n",sep=""))
+    }
     cat(paste("Type of Bootstrap confidence interval used: ", x$ci_type, "\n",sep=""))
 
     cat(paste("Number of bootstrap draws: ", x$boot_rep, "\n",sep=""))
